@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2003 Zope Corporation and Contributors.
+# Copyright (c) 2003 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,9 +12,9 @@
 #
 ##############################################################################
 """Unit tests for zope.sendmail.maildir module
-
-$Id: test_maildir.py 109588 2010-03-03 09:57:07Z kobold $
 """
+from __future__ import print_function
+from __future__ import print_function
 
 import unittest
 import stat
@@ -128,13 +128,13 @@ class FakeOsModule(object):
     def rename(self, old, new):
         self._renamed_files += ((old, new), )
 
-    def open(self, filename, flags, mode=0777):
+    def open(self, filename, flags, mode=0o777):
         if (flags & os.O_EXCL and flags & os.O_CREAT
             and self.access(filename, 0)):
             raise OSError(errno.EEXIST, 'file already exists')
         if not flags & os.O_CREAT and not self.access(filename, 0):
             raise OSError('file not found')
-        fd = max(self._descriptors.keys() + [2]) + 1
+        fd = max(list(self._descriptors.keys()) + [2]) + 1
         self._descriptors[fd] = filename, flags, mode
         return fd
 
@@ -164,7 +164,7 @@ class FakeFile(object):
     def __init__(self, filename, mode):
         self._filename = filename
         self._mode = mode
-        self._written = ''
+        self._written = b''
         self._closed = False
 
     def close(self):
@@ -174,7 +174,7 @@ class FakeFile(object):
         self._written += data
 
     def writelines(self, lines):
-        self._written += ''.join(lines)
+        self._written += b''.join(lines)
 
 
 class TestMaildir(unittest.TestCase):
@@ -211,9 +211,8 @@ class TestMaildir(unittest.TestCase):
         # Case 2b: directory does not exist, create = True
         m = Maildir('/path/to/nosuchfolder', True)
         verifyObject(IMaildir, m)
-        dirs = list(self.fake_os_module._made_directories)
-        dirs.sort()
-        self.assertEquals(dirs, ['/path/to/nosuchfolder',
+        dirs = sorted(self.fake_os_module._made_directories)
+        self.assertEqual(dirs, ['/path/to/nosuchfolder',
                                  '/path/to/nosuchfolder/cur',
                                  '/path/to/nosuchfolder/new',
                                  '/path/to/nosuchfolder/tmp'])
@@ -229,11 +228,11 @@ class TestMaildir(unittest.TestCase):
     def test_iteration(self):
         from zope.sendmail.maildir import Maildir
         m = Maildir('/path/to/maildir')
-        messages = list(m)
-        self.assertEquals(messages, ['/path/to/maildir/cur/2',
-                                     '/path/to/maildir/cur/1',
-                                     '/path/to/maildir/new/2',
-                                     '/path/to/maildir/new/1'])
+        messages = sorted(m)
+        self.assertEqual(messages, ['/path/to/maildir/cur/1',
+                                     '/path/to/maildir/cur/2',
+                                     '/path/to/maildir/new/1',
+                                     '/path/to/maildir/new/2'])
 
     def test_newMessage(self):
         from zope.sendmail.maildir import Maildir
@@ -241,7 +240,7 @@ class TestMaildir(unittest.TestCase):
         m = Maildir('/path/to/maildir')
         fd = m.newMessage()
         verifyObject(IMaildirMessageWriter, fd)
-        self.assert_(fd._filename.startswith(
+        self.assertTrue(fd._filename.startswith(
                      '/path/to/maildir/tmp/1234500002.4242.myhostname.'))
 
     def test_newMessage_never_loops(self):
@@ -257,21 +256,21 @@ class TestMaildir(unittest.TestCase):
         filename2 = '/path/to/maildir/new/1234500002.4242.myhostname'
         fd = FakeFile(filename1, 'w')
         writer = MaildirMessageWriter(fd, filename1, filename2)
-        self.assertEquals(writer._fd._filename, filename1)
-        self.assertEquals(writer._fd._mode, 'w')  # TODO or 'wb'?
-        print >> writer, 'fee',
+        self.assertEqual(writer._fd._filename, filename1)
+        self.assertEqual(writer._fd._mode, 'w')  # TODO or 'wb'?
+        print('fee', end='', file=writer)
         writer.write(' fie')
         writer.writelines([' foe', ' foo'])
-        self.assertEquals(writer._fd._written, 'fee fie foe foo')
+        self.assertEqual(writer._fd._written, b'fee fie foe foo')
 
         writer.abort()
-        self.assertEquals(writer._fd._closed, True)
-        self.assert_(filename1 in self.fake_os_module._removed_files)
+        self.assertEqual(writer._fd._closed, True)
+        self.assertTrue(filename1 in self.fake_os_module._removed_files)
         # Once aborted, abort does nothing
         self.fake_os_module._removed_files = ()
         writer.abort()
         writer.abort()
-        self.assertEquals(self.fake_os_module._removed_files, ())
+        self.assertEqual(self.fake_os_module._removed_files, ())
         # Once aborted, commit fails
         self.assertRaises(RuntimeError, writer.commit)
 
@@ -282,18 +281,18 @@ class TestMaildir(unittest.TestCase):
         fd = FakeFile(filename1, 'w')
         writer = MaildirMessageWriter(fd, filename1, filename2)
         writer.commit()
-        self.assertEquals(writer._fd._closed, True)
-        self.assert_((filename1, filename2)
+        self.assertEqual(writer._fd._closed, True)
+        self.assertTrue((filename1, filename2)
                        in self.fake_os_module._renamed_files)
         # Once commited, commit does nothing
         self.fake_os_module._renamed_files = ()
         writer.commit()
         writer.commit()
-        self.assertEquals(self.fake_os_module._renamed_files, ())
+        self.assertEqual(self.fake_os_module._renamed_files, ())
         # Once commited, abort does nothing
         writer.abort()
         writer.abort()
-        self.assertEquals(self.fake_os_module._renamed_files, ())
+        self.assertEqual(self.fake_os_module._renamed_files, ())
 
     def test_message_writer_unicode(self):
         from zope.sendmail.maildir import MaildirMessageWriter
@@ -301,13 +300,13 @@ class TestMaildir(unittest.TestCase):
         filename2 = '/path/to/maildir/new/1234500002.4242.myhostname'
         fd = FakeFile(filename1, 'w')
         writer = MaildirMessageWriter(fd, filename1, filename2)
-        self.assertEquals(writer._fd._filename, filename1)
-        self.assertEquals(writer._fd._mode, 'w')  # TODO or 'wb'?
-        print >> writer, u'fe\xe8',
+        self.assertEqual(writer._fd._filename, filename1)
+        self.assertEqual(writer._fd._mode, 'w')  # TODO or 'wb'?
+        print(u'fe\xe8', end='', file=writer)
         writer.write(u' fi\xe8')
         writer.writelines([u' fo\xe8', u' fo\xf2'])
-        self.assertEquals(writer._fd._written,
-                          'fe\xc3\xa8 fi\xc3\xa8 fo\xc3\xa8 fo\xc3\xb2')
+        self.assertEqual(writer._fd._written,
+                          b'fe\xc3\xa8 fi\xc3\xa8 fo\xc3\xa8 fo\xc3\xb2')
 
 
 def test_suite():
