@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2003 Zope Corporation and Contributors.
+# Copyright (c) 2003 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -14,13 +14,10 @@
 """Mail Delivery Tests
 
 Simple implementation of the MailDelivery, Mailers and MailEvents.
-
-$Id: test_queue.py 126451 2012-05-23 12:23:18Z tseaver $
 """
-
 import os.path
 import shutil
-
+import sys
 from tempfile import mkdtemp
 from unittest import TestCase, TestSuite, makeSuite, main
 
@@ -28,6 +25,11 @@ from zope.sendmail.queue import ConsoleApp
 from zope.sendmail.tests.test_delivery import MaildirStub, LoggerStub, \
     BrokenMailerStub, SMTPResponseExceptionMailerStub, MailerStub
 
+try:
+    from cStringIO import StringIO
+except ImportError:
+    from io import StringIO
+
 
 class TestQueueProcessorThread(TestCase):
 
@@ -44,6 +46,10 @@ class TestQueueProcessorThread(TestCase):
     def tearDown(self):
         shutil.rmtree(self.dir)
 
+    def test_threadName(self):
+        self.assertEqual(self.thread.getName(),
+                          "zope.sendmail.queue.QueueProcessorThread")
+
     def test_parseMessage(self):
         hdr = ('X-Zope-From: foo@example.com\n'
                'X-Zope-To: bar@example.com, baz@example.com\n')
@@ -51,25 +57,24 @@ class TestQueueProcessorThread(TestCase):
                '\n'
                'Body\n')
         f, t, m = self.thread._parseMessage(hdr + msg)
-        self.assertEquals(f, 'foo@example.com')
-        self.assertEquals(t, ('bar@example.com', 'baz@example.com'))
-        self.assertEquals(m, msg)
+        self.assertEqual(f, 'foo@example.com')
+        self.assertEqual(t, ('bar@example.com', 'baz@example.com'))
+        self.assertEqual(m, msg)
 
     def test_deliveration(self):
         self.filename = os.path.join(self.dir, 'message')
-        temp = open(self.filename, "w+b")
-        temp.write('X-Zope-From: foo@example.com\n'
-                   'X-Zope-To: bar@example.com, baz@example.com\n'
-                   'Header: value\n\nBody\n')
-        temp.close()
+        with open(self.filename, "w+b") as temp:
+            temp.write(b'X-Zope-From: foo@example.com\n'
+                       b'X-Zope-To: bar@example.com, baz@example.com\n'
+                       b'Header: value\n\nBody\n')
         self.md.files.append(self.filename)
         self.thread.run(forever=False)
-        self.assertEquals(self.mailer.sent_messages,
+        self.assertEqual(self.mailer.sent_messages,
                           [('foo@example.com',
                             ('bar@example.com', 'baz@example.com'),
                             'Header: value\n\nBody\n')])
-        self.failIf(os.path.exists(self.filename), 'File exists')
-        self.assertEquals(self.thread.log.infos,
+        self.assertFalse(os.path.exists(self.filename), 'File exists')
+        self.assertEqual(self.thread.log.infos,
                           [('Mail from %s to %s sent.',
                             ('foo@example.com',
                              'bar@example.com, baz@example.com'),
@@ -78,14 +83,13 @@ class TestQueueProcessorThread(TestCase):
     def test_error_logging(self):
         self.thread.setMailer(BrokenMailerStub())
         self.filename = os.path.join(self.dir, 'message')
-        temp = open(self.filename, "w+b")
-        temp.write('X-Zope-From: foo@example.com\n'
-                   'X-Zope-To: bar@example.com, baz@example.com\n'
-                   'Header: value\n\nBody\n')
-        temp.close()
+        with open(self.filename, "w+b") as temp:
+            temp.write(b'X-Zope-From: foo@example.com\n'
+                       b'X-Zope-To: bar@example.com, baz@example.com\n'
+                       b'Header: value\n\nBody\n')
         self.md.files.append(self.filename)
         self.thread.run(forever=False)
-        self.assertEquals(self.thread.log.errors,
+        self.assertEqual(self.thread.log.errors,
                           [('Error while sending mail from %s to %s.',
                             ('foo@example.com',
                              'bar@example.com, baz@example.com'),
@@ -95,17 +99,16 @@ class TestQueueProcessorThread(TestCase):
         # Test a transient error
         self.thread.setMailer(SMTPResponseExceptionMailerStub(451))
         self.filename = os.path.join(self.dir, 'message')
-        temp = open(self.filename, "w+b")
-        temp.write('X-Zope-From: foo@example.com\n'
-                   'X-Zope-To: bar@example.com, baz@example.com\n'
-                   'Header: value\n\nBody\n')
-        temp.close()
+        with open(self.filename, "w+b") as temp:
+            temp.write(b'X-Zope-From: foo@example.com\n'
+                       b'X-Zope-To: bar@example.com, baz@example.com\n'
+                       b'Header: value\n\nBody\n')
         self.md.files.append(self.filename)
         self.thread.run(forever=False)
 
         # File must remail were it was, so it will be retried
-        self.failUnless(os.path.exists(self.filename))
-        self.assertEquals(self.thread.log.errors,
+        self.assertTrue(os.path.exists(self.filename))
+        self.assertEqual(self.thread.log.errors,
                           [('Error while sending mail from %s to %s.',
                             ('foo@example.com',
                              'bar@example.com, baz@example.com'),
@@ -115,19 +118,18 @@ class TestQueueProcessorThread(TestCase):
         # Test a permanent error
         self.thread.setMailer(SMTPResponseExceptionMailerStub(550))
         self.filename = os.path.join(self.dir, 'message')
-        temp = open(self.filename, "w+b")
-        temp.write('X-Zope-From: foo@example.com\n'
-                   'X-Zope-To: bar@example.com, baz@example.com\n'
-                   'Header: value\n\nBody\n')
-        temp.close()
+        with open(self.filename, "w+b") as temp:
+            temp.write(b'X-Zope-From: foo@example.com\n'
+                       b'X-Zope-To: bar@example.com, baz@example.com\n'
+                       b'Header: value\n\nBody\n')
         self.md.files.append(self.filename)
         self.thread.run(forever=False)
 
         # File must be moved aside
-        self.failIf(os.path.exists(self.filename))
-        self.failUnless(os.path.exists(os.path.join(self.dir,
+        self.assertFalse(os.path.exists(self.filename))
+        self.assertTrue(os.path.exists(os.path.join(self.dir,
                                                     '.rejected-message')))
-        self.assertEquals(self.thread.log.errors,
+        self.assertEqual(self.thread.log.errors,
                           [('Discarding email from %s to %s due to a '
                             'permanent error: %s',
                             ('foo@example.com',
@@ -139,19 +141,18 @@ class TestQueueProcessorThread(TestCase):
         self.thread.setMailer(SMTPRecipientsRefusedMailerStub(
                                ['bar@example.com']))
         self.filename = os.path.join(self.dir, 'message')
-        temp = open(self.filename, "w+b")
-        temp.write('X-Zope-From: foo@example.com\n'
-                   'X-Zope-To: bar@example.com, baz@example.com\n'
-                   'Header: value\n\nBody\n')
-        temp.close()
+        with open(self.filename, "w+b") as temp:
+            temp.write(b'X-Zope-From: foo@example.com\n'
+                       b'X-Zope-To: bar@example.com, baz@example.com\n'
+                       b'Header: value\n\nBody\n')
         self.md.files.append(self.filename)
         self.thread.run(forever=False)
 
         # File must be moved aside
-        self.failIf(os.path.exists(self.filename))
-        self.failUnless(os.path.exists(os.path.join(self.dir,
+        self.assertFalse(os.path.exists(self.filename))
+        self.assertTrue(os.path.exists(os.path.join(self.dir,
                                                     '.rejected-message')))
-        self.assertEquals(self.thread.log.errors,
+        self.assertEqual(self.thread.log.errors,
                           [('Email recipients refused: %s',
                            ('bar@example.com',), {})])
 
@@ -175,101 +176,93 @@ class TestConsoleApp(TestCase):
         self.delivery = QueuedMailDelivery(self.queue_dir)
         self.maildir = Maildir(self.queue_dir, True)
         self.mailer = MailerStub()
-        
+        self.real_stderr = sys.stderr
+        self.stderr = StringIO()
+
     def tearDown(self):
+        sys.stderr = self.real_stderr
         shutil.rmtree(self.dir)
 
     def test_args_processing(self):
         # simplest case that works
         cmdline = "zope-sendmail %s" % self.dir
         app = ConsoleApp(cmdline.split(), verbose=False)
-        self.assertEquals("zope-sendmail", app.script_name)
-        self.assertFalse(app._error)
-        self.assertEquals(self.dir, app.queue_path)
+        self.assertEqual("zope-sendmail", app.script_name)
+        self.assertEqual(self.dir, app.queue_path)
         self.assertFalse(app.daemon)
-        self.assertEquals(3, app.interval)
-        self.assertEquals("localhost", app.hostname)
-        self.assertEquals(25, app.port)
-        self.assertEquals(None, app.username)
-        self.assertEquals(None, app.password)
+        self.assertEqual(3, app.interval)
+        self.assertEqual("localhost", app.hostname)
+        self.assertEqual(25, app.port)
+        self.assertEqual(None, app.username)
+        self.assertEqual(None, app.password)
         self.assertFalse(app.force_tls)
         self.assertFalse(app.no_tls)
-        # simplest case that doesn't work
+
+    def test_args_processing_no_queue_path(self):
+        # simplest case that doesn't work: no queue path specified
         cmdline = "zope-sendmail"
-        app = ConsoleApp(cmdline.split(), verbose=False)
-        self.assertEquals("zope-sendmail", app.script_name)
-        self.assertTrue(app._error)
-        self.assertEquals(None, app.queue_path)
-        self.assertFalse(app.daemon)
-        self.assertEquals(3, app.interval)
-        self.assertEquals("localhost", app.hostname)
-        self.assertEquals(25, app.port)
-        self.assertEquals(None, app.username)
-        self.assertEquals(None, app.password)
-        self.assertFalse(app.force_tls)
-        self.assertFalse(app.no_tls)
+        sys.stderr = self.stderr
+        self.assertRaises(SystemExit, ConsoleApp, cmdline.split(), verbose=False)
+
+    def test_args_processing_almost_all_options(self):
         # use (almost) all of the options
         cmdline = "zope-sendmail --daemon --interval 7 --hostname foo --port 75 " \
             "--username chris --password rossi --force-tls " \
             "%s" % self.dir
         app = ConsoleApp(cmdline.split(), verbose=False)
-        self.assertEquals("zope-sendmail", app.script_name)
-        self.assertFalse(app._error)
-        self.assertEquals(self.dir, app.queue_path)
+        self.assertEqual("zope-sendmail", app.script_name)
+        self.assertEqual(self.dir, app.queue_path)
         self.assertTrue(app.daemon)
-        self.assertEquals(7, app.interval)
-        self.assertEquals("foo", app.hostname)
-        self.assertEquals(75, app.port)
-        self.assertEquals("chris", app.username)
-        self.assertEquals("rossi", app.password)
+        self.assertEqual(7, app.interval)
+        self.assertEqual("foo", app.hostname)
+        self.assertEqual(75, app.port)
+        self.assertEqual("chris", app.username)
+        self.assertEqual("rossi", app.password)
         self.assertTrue(app.force_tls)
         self.assertFalse(app.no_tls)
+
+    def test_args_processing_username_without_password(self):
         # test username without password
         cmdline = "zope-sendmail --username chris %s" % self.dir
-        app = ConsoleApp(cmdline.split(), verbose=False)
-        self.assertTrue(app._error)
-        # test --tls and --no-tls together
-        cmdline = "zope-sendmail --tls --no-tls %s" % self.dir
-        app = ConsoleApp(cmdline.split(), verbose=False)
-        self.assertTrue(app._error)
+        sys.stderr = self.stderr
+        self.assertRaises(SystemExit, ConsoleApp, cmdline.split(), verbose=False)
+
+    def test_args_processing_force_tls_and_no_tls(self):
         # test force_tls and no_tls
-        comdline = "zope-sendmail --force-tls --no-tls %s" % self.dir
-        self.assertTrue(app._error)
-        
+        cmdline = "zope-sendmail --force-tls --no-tls %s" % self.dir
+        sys.stderr = self.stderr
+        self.assertRaises(SystemExit, ConsoleApp, cmdline.split(), verbose=False)
+
     def test_ini_parse(self):
         ini_path = os.path.join(self.dir, "zope-sendmail.ini")
-        f = open(ini_path, "w")
-        f.write(test_ini)
-        f.close()
+        with open(ini_path, "w") as f:
+            f.write(test_ini)
         # override most everything
         cmdline = """zope-sendmail --config %s""" % ini_path
         app = ConsoleApp(cmdline.split(), verbose=False)
-        self.assertEquals("zope-sendmail", app.script_name)
-        self.assertFalse(app._error)
-        self.assertEquals("hammer/dont/hurt/em", app.queue_path)
+        self.assertEqual("zope-sendmail", app.script_name)
+        self.assertEqual("hammer/dont/hurt/em", app.queue_path)
         self.assertFalse(app.daemon)
-        self.assertEquals(33, app.interval)
-        self.assertEquals("testhost", app.hostname)
-        self.assertEquals(2525, app.port)
-        self.assertEquals("Chris", app.username)
-        self.assertEquals("Rossi", app.password)
+        self.assertEqual(33, app.interval)
+        self.assertEqual("testhost", app.hostname)
+        self.assertEqual(2525, app.port)
+        self.assertEqual("Chris", app.username)
+        self.assertEqual("Rossi", app.password)
         self.assertFalse(app.force_tls)
         self.assertTrue(app.no_tls)
         # override nothing, make sure defaults come through
-        f = open(ini_path, "w")
-        f.write("[app:zope-sendmail]\n\nqueue_path=foo\n")
-        f.close()
+        with open(ini_path, "w") as f:
+            f.write("[app:zope-sendmail]\n\nqueue_path=foo\n")
         cmdline = """zope-sendmail --config %s %s""" % (ini_path, self.dir)
         app = ConsoleApp(cmdline.split(), verbose=False)
-        self.assertEquals("zope-sendmail", app.script_name)
-        self.assertFalse(app._error)
-        self.assertEquals(self.dir, app.queue_path)
+        self.assertEqual("zope-sendmail", app.script_name)
+        self.assertEqual(self.dir, app.queue_path)
         self.assertFalse(app.daemon)
-        self.assertEquals(3, app.interval)
-        self.assertEquals("localhost", app.hostname)
-        self.assertEquals(25, app.port)
-        self.assertEquals(None, app.username)
-        self.assertEquals(None, app.password)
+        self.assertEqual(3, app.interval)
+        self.assertEqual("localhost", app.hostname)
+        self.assertEqual(25, app.port)
+        self.assertEqual(None, app.username)
+        self.assertEqual(None, app.password)
         self.assertFalse(app.force_tls)
         self.assertFalse(app.no_tls)
 
